function Y = Wiener_filter( O, I, e)
% WIENER_FILTER provides a 1-D filter for desensitizing
% division in the frequency domain (deconvolution) to noise.
% The filter takes a sampled output spectrum ,O, and an 
% input spectrum, I, and computes Y = O*conj(I)/(|I|^2 + e^2*M^2)
% where M is the maximum value of |I| and conj(I) is the
% complex conjugate of I. The constant e is generally taken as
% a constant to represent the noise level. Small values of e 
% such as e = 0.01 to 0.05 often work well for ultrasonic systems.
%The calling sequence is:
%   Y = Wiener_filter(O,I,e);
%
M = max(abs(I));
Y = O.*conj(I)./((abs(I)).^2 + e^2*M^2);