function T12 = smooth_solid(setup)
% SMOOTH_SOLID(SETUP) computes the P-P (tpp)
% and P-S (tps) transmission coefficients based on velocity ratios
% for two solids in smooth contact. It obtains the necessary input
% parameters from the setup structure and then returns the 
% appropriate transmission coefficient
%
% Note: If setup.matl.cs1 = 0  the values returned are for a fluid-solid interface.

% get setup parameters
type1 =setup.type1;
type2 =setup.type2;
inc= setup.geom.i_ang;
d1 = setup.matl.d1;
d2 =setup.matl.d2;
cp1 = setup.matl.cp1;
cs1 =setup.matl.cs1;
cp2 =setup.matl.cp2;
cs2 =setup.matl.cs2;

% consistency check (if incident wave in medium 1 is an S-wave
% then can't use this fluid-solid trans. coefficient)

if strcmp(type1, 's') 
    error('wrong wave type for medium 1')
end
iang = (inc.*pi)./180;  %change degrees to radians

%calculate sines and cosines of all incident and refracted angles
sinp1 = sin(iang);
cosp1 = sqrt(1-sinp1.^2);
sins1 = (cs1/cp1)*sin(iang);
coss1= sqrt(1-sins1.^2);
sinp2 = (cp2/cp1)*sin(iang);
sins2 =(cs2/cp1)*sin(iang);
    % take into account cosines of refracted angles may be imaginary beyond
    % critical angles 
cosp2= (i*sqrt(sinp2.^2 - 1)).*(sinp2 >= 1) + ...
    (sqrt(1 - sinp2.^2)).*(sinp2 < 1);
coss2 = (i*sqrt(sins2.^2 - 1)).*(sins2 >= 1) + ...
    (sqrt(1 - sins2.^2)).*(sins2 < 1);

%calculate transmission coefficients
denom1 = (cp1/cp2).*(cosp2./cosp1).*...
    (4.*((cs1/cp1)^2).*(sins1.*coss1.*sinp1.*cosp1) + ...
    1 - 4.*(sins1.^2).*(coss1.^2));
denom2 = (d2/d1).*(4.*((cs2/cp2)^2).*(sins2.*coss2.*sinp2.*cosp2) ...
		+ 1 - 4.*(sins2.^2).*(coss2.^2));
    denom = denom1 + denom2;
   
tpp = ((2*cp1/cp2).*(1-2*sins1.^2).*(1-2*sins2.^2))./denom;
tps = -((4*cp1*cs2/(cp2^2)).*sinp2.*cosp2.*(1-2*sins1.^2))./denom;


%select appropriate coefficient
if strcmp(type2, 'p')
    T12 = tpp;
elseif strcmp(type2, 's')
    T12 = tps;
else
    error('wrong wave type specification')
end