function [Vf, setup] =SDH_PE_MM(setup)
% SDH_PE_MM generates the frequency components of the 
% output voltage, Vf, of an ultrasonic pulse-echo immersion
% measurement system generated by a side-drilled hole. 
% The function returns Vf  as well as an updated setup structure
% The calling sequence is [Vf, setup] =SDH_PE_MM(setup);

% First, compute the integrated beam velocity squared term 
% and update the setup structure. This does not include 
% attenuation 
[vs, setup] = I_MGbeam(setup);

%get the setup parameters  needed for the constant term
%in the measurement model
f = setup.f;
r= setup.trans.d/2;    % transducer radius
d1 =setup.matl.d1;
d2 =setup.matl.d2;
c1 = setup.wave.c1;
c2 = setup.wave.c2;

%compute wave number in medium two and 
%the constant term in the measurement model

k2 = (2000.*pi.*f)./c2;
k2 =k2 + eps*( k2 == 0);  % prevent division by zero
K= (4.*d2.*c2)./(-i.*k2.*r^2.*d1.*c1);

% check to see if a model-based or experimentally determined system
% function is to be used
if strcmp(setup.system.sysf, 'systf')
    sys = systf(setup);
else
    sys =feval(setup.system.sysf, setup);
end

% find flaw type to be used
if strcmp( setup.flaw.Afunc, 'empty')
    error('flaw function not specified in setup')
else
    A = feval(setup.flaw.Afunc, setup);
end

%compute output voltage, Vf, (volts/MHz)
Vf = sys.*(vs).*(attenuate(setup)).^2.*A.*K;


    