function y = systf (setup)
% SYSTF returns the system function as modeled by a Gaussian window function 
% of amplitude amp centered at frequency fc and with a bandwidth bw defined to  
% be the spread in frequency at the half amplitude point in the Gaussian. These
% parameters are obtained from the setup structure which is the only input
% argument of this function.
% The Gaussian is tapered to zero at frequencies below fc with a sine function to 
% guarantee the dc value is always zero.
% For small fc and large bw, this tapering will distort the Gaussian
% The calling sequence for this function is:
% y =systf(setup);

% retrieve setup parameters
f =setup.f;
amp = setup.system.amp;
fc = setup.system.fc;
bw = setup.system.bw;
% compute the 'a' parameter and define system function above and below the
% center frequency
a = sqrt(log(2))/(pi*bw);
s1 = exp(-(2*a*pi*(f - fc)).^2).*(f > fc);
s2 = exp(-(2*a*pi*(f - fc)).^2).*sin(pi*f/(2*fc)).*(f <= fc);
% combine terms to obtain total system function
y = amp*(s1 + s2); 
