% FBH_example1 script
% This script calculates the pulse-echo P-wave response of an on-axis 
% #8 flat-bottom hole interrogated by a 5 MHz planar probe through a 
% fluid-solid interface at normal incidence
clear
setup = setup_maker;
% setup parameters that need to be specified
% for this example
f =s_space(0, 20, 200);
cp1 = 1484.;
d2 = 7.86;
cp2 = 5940.;
cs2 = 3230.;
z1 = 50.8;
z2 = 25.4;
amp =0.12;
bw = 3.;
z1r =50.8;
p1 = [ 0 0 0.02479E-03  0 0];
b =1.5875;   % number eight FBH
flaw_name = 'A_crack';
sysfunc ='exp_systf';
reffile='FBH_ref';
setup.f =f;
setup.system.amp = amp;
setup.system.bw = bw;
setup.system.z1r =z1r;
setup.system.sysf = sysfunc;
setup.system.ref_file = reffile;
setup.geom.z1 = z1;
setup.geom.z2 = z2;
setup.matl.cp1 = cp1;
setup.matl.d2 = d2;
setup.matl.cp2 = cp2;
setup.matl.cs2 = cs2;
setup.matl.p1 = p1;
setup.flaw.b = b;
setup.flaw.Afunc = flaw_name;
% break up hole end into rings
nR= 10;  % use 9 rings (10 points)
rm = linspace(0, b, nR);    %ring edges
rmu = rm(2:nR); %upper edges
rml =rm(1:nR-1); %lower edges
rc =(rmu-rml)/2 + rml; %ring centroids
rc(1) = 0; %make first centroid at origin 

Vf = zeros(size(f));

% calculate received voltage
for nd = 1:nR-1
    setup.geom.x2 = rc(nd);
    setup.flaw.b =rm(nd);
    [Vf1, setup] = TG_PE_MM(setup);
    setup.flaw.b = rm(nd+1);
    [Vf2, setup] = TG_PE_MM(setup);
    Vf = (Vf2-Vf1) +Vf;
end
% extend frequency components to permit
% taking FFT
df = f(2)-f(1);
dt = 1/(1000*df);
t = s_space(0, 1000*dt, 1000);
Vfe = [Vf zeros(1,800)];
Vfe(1) = Vfe(1)/2;
vt =2*real(IFourierT(Vfe, dt));
vs =c_shift(vt, 700);
plot(t(100:500), vs(100:500))
%plot(t_shift(t,700), c_shift(vt,700))
hold on
load 'FBH_flaw_n8';
plot(t(100:500), vexp(250:650), '--')
hold off
