%SDH_deconvolve1 script
% This script uses the measured pulse-echo P-wave response of an on-axis 
% 1 mm diam side-drilled hole interrogated by a 5 MHz planar probe through a 
% fluid-solid interface at normal incidence and the side-drilled hole
% measurement model for this case to obtain an experimental far field scattering
% amplitude for the hole by deconvolution. this experimental result is plotted versus
% frequency and compared to the theoretical scattering amplitude caluclated
% by the method of separation of variables.
clear
setup = setup_maker;
% setup parameters that need to be specified
% for this example
f =s_space(0, 20, 200);
y2 =linspace(-50, 50, 500);
cp1 = 1484.;
d2 = 2.75;
cp2 = 6416.;
cs2 = 3163.;
z1 = 50.8;
z2 = 25.4;
amp =0.12;
bw = 3.;
z1r =50.8;
en =0.03;   % noise parameter for this example
p1 = [ 0 0 0.02479E-03  0 0];
b =0.5;   % 0.5 mm radius
flaw_name = 'A_unity';  % scattering amplitude set to unity
sysfunc ='exp_systf';
reffile='SDH_ref';
setup.f =f;
setup.system.amp = amp;
setup.system.bw = bw;
setup.system.z1r =z1r;
setup.system.sysf = sysfunc;
setup.system.ref_file = reffile;
setup.system.en = en;
setup.geom.z1 = z1;
setup.geom.z2 = z2;
setup.geom.y2 = y2;
setup.matl.cp1 = cp1;
setup.matl.d2 = d2;
setup.matl.cp2 = cp2;
setup.matl.cs2 = cs2;
setup.matl.p1 = p1;
setup.flaw.b = b;
setup.flaw.Afunc = flaw_name;
% calculate all terms in measurement model except scattering amplitude  
[G, setup] = SDH_PE_MM(setup);
% get experimental wave form and calculate FFT
load 'SDH_flaw_1';  % loads time and voltage variables into texp and vexp
dt = texp(2) - texp(1);
Vf = FourierT(vexp, dt);
% consider only same number of frequency components as modeled
Vfl = Vf(1:200);
% compute Wiener filter with en value in setup
Aexp =Wiener_filter(Vfl, G, en);
% plot experimental scattering amplitude
plot(f,abs(Aexp))
hold on
% compare with theoretical scattering amplitude calculated 
% by separation of variables
Asep = A_SDH_Psep(setup);
plot(f, abs(Asep), ':');
hold off
