%SDH_example1 script
% This script calculates the pulse-echo P-wave response of an on-axis 
% 1 mm diam side-drilled hole hole interrogated by a 5 MHz planar probe through a 
% fluid-solid interface at normal incidence
clear
setup = setup_maker;
% setup parameters that need to be specified
% for this example
f =s_space(0, 20, 200);
y2 =linspace(-50, 50, 500);
cp1 = 1484.;
d2 = 2.75;
cp2 = 6416.;
cs2 = 3163.;
z1 = 50.8;
z2 = 25.4;
amp =0.12;
bw = 3.;
z1r =50.8;
p1 = [ 0 0 0.02479E-03  0 0];
b =0.5;   % 0.5 mm radius
flaw_name = 'A_SDH';
sysfunc ='exp_systf';
reffile='SDH_ref';
setup.f =f;
setup.system.amp = amp;
setup.system.bw = bw;
setup.system.z1r =z1r;
setup.system.sysf = sysfunc;
setup.system.ref_file = reffile;
setup.geom.z1 = z1;
setup.geom.z2 = z2;
setup.geom.y2 = y2;
setup.matl.cp1 = cp1;
setup.matl.d2 = d2;
setup.matl.cp2 = cp2;
setup.matl.cs2 = cs2;
setup.matl.p1 = p1;
setup.flaw.b = b;
setup.flaw.Afunc = flaw_name;
  
[Vf, setup] = SDH_PE_MM(setup);

% extend frequency components to permit
% taking FFT
df = f(2)-f(1);
dt = 1/(1000*df);
t = s_space(0, 1000*dt, 1000);
Vfe = [Vf zeros(1,800)];
Vfe(1) = Vfe(1)/2;
vt =2*real(IFourierT(Vfe, dt));
vs =c_shift(vt, 700);
plot(t, vs)
hold on
load 'SDH_flaw_1';
plot(t, vexp, '--')
hold off
