function [t, vt] = model_pulser(energy, damping, RL)
% MODEL_PULSER takes as inputs an energy setting (energy = 1,2,3,4),
% a damping setting (damping = 0,5,10), and a specified resistance
% RL in ohms (for open circuit RL = inf) and calculaters the output
% voltage, vt (volts), of the pulser as a function of time, t,  across RL.
% The calling sequence is [t, vt] = model_pulser(energy, damping, RL)

%energy setting
switch energy
case 1
    A = 1;
case 2
    A = 1.2;
case 3
    A = 1.4;
case 4
    A = 1.6;
otherwise
    error('energy setting must be 1, 2, 3, or 4')
end
%damping setting
switch damping
case 0
    R = 60;
case 5
    R = 45;
case 10
    R = 10;
otherwise
    error('damping setting must be 0, 5, or 10')
end
% calculate source voltage Vout (pulserV function)
V0 =200;
t0 = 0.01;
a1 = 0.2;
a2 = 50;
f = linspace(0, 200, 512);
f = f + eps*(f ==0);
Vinf = V0/(1 -exp(-a1*t0));
arg1 = a1 - i*2*pi*f;
arg2 = a2 - i*2*pi*f;
Vout = Vinf*(1-exp(-arg1*t0))./arg1 + Vinf*(1 -exp(i*2*pi*f*t0))./(i*2*pi*f) ...
    -V0*exp(i*2*pi*f*t0)./arg2;
% end  source voltage calculation
RC = 0.2;
% calculate Thevenin source term and equivalent impedance for pulser
Vs = A*Vout;  
Z = R./(1-2*pi*i*RC*f);
% calculate voltage across a given load RL
if RL ==0
    VL =zeros(1,512);
    disp('ZAP!! You have just shorted the pulser')
else
    VL = Vs./(1+Z/RL);
end
VL = [VL zeros(1,512)];
VL(1) = VL(1)/2;
fmax =2*f(end);
dt = 1/fmax;
df = f(2) - f(1);
t = linspace(0, 1/df, 1024);
vt = 2*real((df)*fft(VL));