function [Rp, Rs] = stress_freeP(ang, cp, cs)
%stress_freeP(ang, cp, cs) computes the plane wave
%reflection coefficients (based on velocity ratios)
%for a P-wave incident on a plane,stress free surface
%of an elastic solid. The calling sequence is:
%[Rp, Rs] = free_surfaceP(ang, cp, cs);
%where ang is the incident angle in degrees,
%cp, cs are the P- and S-wave speeds, respectively,
%and Rp, Rs are the reflection coefficients for
%the reflected P-waves and S-waves, respectively.
iang =ang*pi/180;
sinp1= sin(iang);
sins1 = (cs/cp).*sinp1;
sin2p1 = 2.*sinp1.*sqrt(1-sinp1.^2);
sin2s1 = 2.*sins1.*sqrt(1-sins1.^2);
cos2s1 = (1-2.*sins1.^2);
delta = sin2p1.*sin2s1 +((cp/cs)^2).*(cos2s1.^2);
Rp = (sin2p1.*sin2s1 -((cp/cs)^2).*cos2s1.^2)./delta;
Rs = -(2*(cp/cs).*sin2p1.*cos2s1)./delta;
