function y = t_a(f, a, d, d1, d2, c1, c2)
%t_a (f, a, d1, d2, c1, c2) calculates the acoustic/elastic
%transfer function for the reflection of the wave field off a
% planar surface of a solid at a distance d (in mm) from a circular
% planar immersion piston transducer of radius a (in mm). The frequency,
% f is in MHz and the densities of the fluid and solid (d1, and d2), 
% are in gm/cm^3. The wavespeeds c1, c2 of the fluid and solid,
% respectively, are in m/sec. The phase term exp(2*i*k*d) in 
% this transfer function is omitted.

ka = 2000*pi*f*a./c1;
a2d = a/(2*d);
R12 = (d2*c2 -d1*c1)/(d1*c1 + d2*c2);
% next line includes attenuation of the water 
%att =(25.3E-06)*f.^2;
att =0.;
u = ka.*a2d;
D = 2.*(1-exp(i.*u).*(besselj(0,u) - i.*besselj(1, u)));
y= R12.*D.*exp(-(2*d)*att);